@@ -361,6 +361,7 @@ def app():
         help="A file containing regexes " "(the default is regexes.json).",
         advanced=True,
         caption="Файл с регулярными выражениями",
+        argtype="filename"
     )
     cmdparse.add_argument(
         "--parsedir",
@@ -380,6 +381,18 @@ def app():
         advanced=True,
         caption="Стратегия обработки ссылок",
     )
+    cmdparse.add_argument(
+        "--numbers_handling",
+        default="default",
+        choices=["default", "all", "none"],
+        help="question numbers handling strategy. "
+        "Default preserves zero questions and numbering "
+        "if the first question has number > 1, omits number otherwise. "
+        "All preserves all numbers, none omits all numbers "
+        "(was default behaviour pre-0.8.0.)",
+        advanced=True,
+        caption="Стратегия обработки номеров вопросов",
+    )
     cmdparse.add_argument(
         "--fix_spans",
         action="store_true",
@@ -412,6 +425,13 @@ def app():
         caption="Не добавлять временную отметку в имя файла",
         advanced=True,
     )
+    cmdcompose.add_argument(
+        "--labels_file",
+        help="i18n config",
+        caption="Конфиг для интернационализации",
+        advanced=True,
+        argtype="filename"
+    )
     cmdcompose_filetype = cmdcompose.add_subparsers(dest="filetype")
     cmdcompose_docx = cmdcompose_filetype.add_parser("docx")
     cmdcompose_docx.add_argument(
@@ -646,6 +666,8 @@ def app():
 
     args = parser.parse_args()
 
+    if not args.labels_file:
+        args.labels_file = os.path.join(resourcedir, "labels_ru.toml")
     if not args.regexes:
         args.regexes = os.path.join(resourcedir, "regexes.json")
     if not args.docx_template:
