@@ -325,9 +325,13 @@ def chgk_parse(text, defaultauthor=None, regexes=None):
                     structure.insert(_id, ["number", num])
                 except:
                     pass
+            # TODO: переделать корявую обработку авторки на нормальную
+            before_replacement = element[1]
             element[1] = regexes[element[0]].sub("", element[1])
             if element[1].startswith(SEP):
                 element[1] = element[1][len(SEP) :]
+            if element[0] == "author" and "авторка:" in before_replacement.lower():
+                element[1] = "!!Авторка" + element[1]
 
     if debug:
         with codecs.open("debug_4.json", "w", "utf8") as f:
@@ -625,7 +629,7 @@ def remove_double_separators(s):
     return re.sub(r"({})+".format(SEP), SEP, s)
 
 
-def compose_4s(structure):
+def compose_4s(structure, args=None):
     types_mapping = {
         "meta": "# ",
         "tour": "## ",
@@ -667,15 +671,18 @@ def compose_4s(structure):
                     )
                 )
 
+    def tryint(s):
+        try:
+            return int(s)
+        except (TypeError, ValueError):
+            return
+
+    def is_zero(s):
+        return str(s).startswith("0") or not tryint(s)
+
     result = ""
+    first_number = True
     for element in structure:
-        if element[0] in ["tour", "tourrev"]:
-            checkNumber = True
-        if element[0] == "number" and checkNumber and int(element[1]) != 0:
-            checkNumber = False
-            result += "№№ " + element[1] + SEP
-        if element[0] == "number" and int(element[1]) == 0:
-            result += "№ " + element[1] + SEP
         if element[0] in types_mapping and types_mapping[element[0]]:
             result += (
                 types_mapping[element[0]]
@@ -685,10 +692,25 @@ def compose_4s(structure):
             )
         elif element[0] == "Question":
             tmp = ""
+            overrides = element[1].get("overrides") or {}
+            if "number" in element[1]:
+                if args.numbers_handling == "default":
+                    if is_zero(element[1]["number"]):
+                        tmp += "№ " + element[1]["number"] + SEP
+                    elif first_number and tryint(element[1]["number"]) > 1:
+                        tmp += "№№ " + element[1]["number"] + SEP
+                elif args.numbers_handling == "all":
+                    tmp += "№ " + element[1]["number"] + SEP
+                if not is_zero(element[1]["number"]):
+                    first_number = False
             for label in QUESTION_LABELS:
+                override_label = "" if label not in overrides else (
+                    "!!{} ".format(overrides[label])
+                )
                 if label in element[1] and label in types_mapping:
                     tmp += (
                         types_mapping[label]
+                        + override_label
                         + format_element(element[1][label])
                         + SEP
                     )
@@ -721,7 +743,7 @@ def chgk_parse_wrapper(path, args, regexes=None):
     outfilename = os.path.join(target_dir, make_filename(abspath))
     logger.info("Output: {}".format(os.path.abspath(outfilename)))
     with codecs.open(outfilename, "w", "utf8") as output_file:
-        output_file.write(compose_4s(final_structure))
+        output_file.write(compose_4s(final_structure, args=args))
     return outfilename
 
 
